==> merchant-base-0.4.18-RELEASE-sources.jar: com/rocogz/merchant/entity/scm/MerchantScmProductInformation.java <==
package com.rocogz.merchant.entity.scm;

import com.baomidou.mybatisplus.annotation.TableField;
import com.rocogz.merchant.constant.Constant;
import com.rocogz.merchant.entity.agent.goods.MerchantAgentGoods;
import com.rocogz.merchant.entity.customer.goods.MerchantCustomerGoods;
import com.rocogz.merchant.entity.goods.MerchantGoods;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;

/**
 * <p>
 * 产品信息
 * </p>
 *
 * @author liangyongtong
 * @since 2021-03-09
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantScmProductInformation extends IdEntity {

    private static final long serialVersionUID=1L;

    /**
     * 订单号
     */
    private String orderCode;

    /**
     * 合作客户产品编码
     * @see MerchantCustomerGoods#code
     */
    private String customerProductCode;

    /**
     * 合作客户产品名称
     */
    private String customerProductName;

    /**
     * 合作客户产品采购价格
     * @see MerchantCustomerGoods#settlePrice
     */
    private BigDecimal customerPurchasePrice;

    /**
     * 合作客户产品市场价/面额
     * @see MerchantCustomerGoods#marketPrice
     */
    private BigDecimal customerMarketPrice;

    /**
     * 合作客户结算采购价
     * @see MerchantCustomerGoods#purchaseSettlePrice
     */
    private BigDecimal customerPurchaseSettlePrice;

    /**
     * 代理商产品编码
     */
    private String agentProductCode;

    /**
     * 代理商产品名称
     */
    private String agentProductName;

    /**
     * 代理商产品采购价格
     * @see MerchantAgentGoods#purchasePrice
     */
    private BigDecimal agentPurchasePrice;

    /**
     * 代理商产品市场价/面额
     * @see MerchantAgentGoods#marketPrice
     */
    private BigDecimal agentMarketPrice;

    /**
     * 代理商结算采购价
     * @see MerchantAgentGoods#purchaseSettlePrice
     */
    private BigDecimal agentPurchaseSettlePrice;

    /**
     * 平台编码
     */
    private String productCode;

    /**
     * 平台名称
     */
    private String productName;

    /**
     * 产品性质:单品,供应商定制套餐、平台定制套餐
     * @see Constant.DictData#GOODS_NATURE_ITEM
     * @see MerchantGoods#goodsNature
     */
    private String productNature;

    /**
     * 平台供应商产品编码
     */
    @TableField(exist = false)
    private String thirdProductCode;

    /**
     * 平台采购价格
     * @see MerchantGoods#costPrice
     */
    private BigDecimal purchasePrice;

    /**
     * 平台市场价/面额
     * @see MerchantGoods#marketPrice
     */
    private BigDecimal marketPrice;

    /**
     * 产品类别：加油代金券、电子油卡券直充
     * @see Constant.DictData#PRODUCT_TYPE_OIL_CARD_DIGITAL_YES
     * @see MerchantGoods#goodsType
     */
    private String productType;

    /**
     * 产品使用规则:原基准券编号
     */
    private String couponCode;

    //不存在表中，列表上需要显示
    /**
     * 产品类型名字
     */
    @TableField(exist = false)
    private String goodsTypeName;


}

==> merchant-base-0.4.29-RELEASE-sources.jar: com/rocogz/merchant/entity/scm/MerchantScmProductInformation.java <==
package com.rocogz.merchant.entity.scm;

import com.baomidou.mybatisplus.annotation.TableField;
import com.rocogz.merchant.constant.Constant;
import com.rocogz.merchant.entity.agent.goods.MerchantAgentGoods;
import com.rocogz.merchant.entity.customer.goods.MerchantCustomerGoods;
import com.rocogz.merchant.entity.goods.MerchantGoods;
import com.rocogz.merchant.entity.goods.MerchantGoodsMeal;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;

/**
 * <p>
 * 产品信息
 * </p>
 *
 * @author liangyongtong
 * @since 2021-03-09
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantScmProductInformation extends IdEntity {

    private static final long serialVersionUID=1L;

    /**
     * 订单号
     */
    private String orderCode;

    /**
     * 合作客户产品编码
     * @see MerchantCustomerGoods#code
     */
    private String customerProductCode;

    /**
     * 合作客户产品名称
     */
    private String customerProductName;

    /**
     * 合作客户产品采购价格
     * @see MerchantCustomerGoods#settlePrice
     */
    private BigDecimal customerPurchasePrice;

    /**
     * 合作客户产品市场价/面额
     * @see MerchantCustomerGoods#marketPrice
     */
    private BigDecimal customerMarketPrice;

    /**
     * 合作客户结算采购价
     * @see MerchantCustomerGoods#purchaseSettlePrice
     */
    private BigDecimal customerPurchaseSettlePrice;

    /**
     * 代理商产品编码
     */
    private String agentProductCode;

    /**
     * 代理商产品名称
     */
    private String agentProductName;

    /**
     * 代理商产品采购价格
     * @see MerchantAgentGoods#purchasePrice
     */
    private BigDecimal agentPurchasePrice;

    /**
     * 代理商产品市场价/面额
     * @see MerchantAgentGoods#marketPrice
     */
    private BigDecimal agentMarketPrice;

    /**
     * 代理商结算采购价
     * @see MerchantAgentGoods#purchaseSettlePrice
     */
    private BigDecimal agentPurchaseSettlePrice;

    /**
     * 平台编码
     */
    private String productCode;

    /**
     * 平台名称
     */
    private String productName;

    /**
     * 产品性质:单品,供应商定制套餐、平台定制套餐
     * @see Constant.DictData#GOODS_NATURE_ITEM
     * @see MerchantGoods#goodsNature
     */
    private String productNature;

    /**
     * 平台供应商产品编码
     */
    @TableField(exist = false)
    private String thirdProductCode;

    /**
     * 平台采购价格
     * @see MerchantGoods#costPrice
     */
    private BigDecimal purchasePrice;

    /**
     * 平台市场价/面额
     * @see MerchantGoods#marketPrice
     */
    private BigDecimal marketPrice;

    /**
     * 产品类别：加油代金券、电子油卡券直充
     * @see Constant.DictData#PRODUCT_TYPE_OIL_CARD_DIGITAL_YES
     * @see MerchantGoods#goodsType
     */
    private String productType;

    /**
     * 产品使用规则:原基准券编号
     */
    private String couponCode;

    //不存在表中，列表上需要显示
    /**
     * 产品类型名字
     */
    @TableField(exist = false)
    private String goodsTypeName;


    /**
     * 使用有效期-结束日期 (天)
     * @see MerchantGoods#useValidity
     */
    @TableField(exist = false)
    private Integer useValidity;

}
